#! /usr/bin/env node
'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _packageData = require('../packageData');

var _packageData2 = _interopRequireDefault(_packageData);

var _constants = require('../constants');

var _mapKeyToKey = require('./helpers/mapKeyToKey');

var _mapKeyToKey2 = _interopRequireDefault(_mapKeyToKey);

var _mapSet = require('./helpers/mapSet');

var _mapSet2 = _interopRequireDefault(_mapSet);

var _mapSetIndexed = require('./helpers/mapSetIndexed');

var _mapSetIndexed2 = _interopRequireDefault(_mapSetIndexed);

var _mapSetGrouped = require('./helpers/mapSetGrouped');

var _mapSetGrouped2 = _interopRequireDefault(_mapSetGrouped);

var _writeFile = require('./helpers/writeFile');

var _writeFile2 = _interopRequireDefault(_writeFile);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createFilePath(name) {
  return _path2.default.join(__dirname, `../../data/${name}`);
}
/**
 * @copyright   2017, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 */

function generateFormat(rawData, format) {
  console.log(`Generating data for ${format} format`);

  return Promise.resolve(rawData).then(data => (0, _writeFile2.default)(createFilePath(`${format}/list.json`), data, dump => (0, _mapSet2.default)(dump, format))).then(data => (0, _writeFile2.default)(createFilePath(`${format}/map.json`), data, dump => (0, _mapSetIndexed2.default)(dump, 'hexcode', format))).then(data => (0, _writeFile2.default)(createFilePath(`${format}/by-category.json`), data, dump => (0, _mapSetGrouped2.default)(dump, 'category', format)));
}

function generateExtra(rawData) {
  console.log('Generating extra data');

  return Promise.resolve(rawData).then(data => (0, _writeFile2.default)(createFilePath('extra/hexcodes.json'), data, dump => dump.map(row => row.hexcode))).then(data => (0, _writeFile2.default)(createFilePath('extra/shortnames.json'), data, dump => dump.map(row => row.shortnames[0]))).then(data => (0, _writeFile2.default)(createFilePath('extra/unicode.json'), data, dump => dump.map(row => row[row.display]))).then(data => (0, _writeFile2.default)(createFilePath('extra/hexcode-to-shortname.json'), data, dump => (0, _mapKeyToKey2.default)(dump, 'hexcode', 'shortname'))).then(data => (0, _writeFile2.default)(createFilePath('extra/shortname-to-unicode.json'), data, dump => (0, _mapKeyToKey2.default)(dump, 'shortname', 'unicode')));
}

const data = (0, _packageData2.default)();

const remainingEmojiOnes = Object.values(_packageData.EMOJI_ONE);

if (remainingEmojiOnes.length > 0) {
  console.log(_chalk2.default.yellow('Not all EmojiOne definitions have been used!'));

  remainingEmojiOnes.forEach(emoji => {
    console.log(_chalk2.default.gray(`  ${emoji.name}`));
  });
}

Promise.all([generateFormat(data, _constants.EXPANDED), generateFormat(data, _constants.STANDARD), generateFormat(data, _constants.COMPACT), generateExtra(data)]).then(() => {
  console.log(_chalk2.default.green('Data dumps generated successfully'));
}).catch(error => {
  console.log(_chalk2.default.red('Failed to generate data dumps'));
  console.log(_chalk2.default.gray(error.message));
});