#! /usr/bin/env node
'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _regexgen = require('regexgen');

var _packageData = require('../packageData');

var _packageData2 = _interopRequireDefault(_packageData);

var _writeFile = require('./helpers/writeFile');

var _writeFile2 = _interopRequireDefault(_writeFile);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function generateRegex(rawData, display) {
  console.log(`Generating ${display} regex pattern`);

  const fileName = display === 'both' ? 'index' : display;
  const codePointGroups = {
    4: new _regexgen.Trie(),
    3: new _regexgen.Trie(),
    2: new _regexgen.Trie(),
    1: new _regexgen.Trie()
  };

  return Promise.resolve(rawData).then(data => {
    data.forEach(emoji => {
      const group = emoji.codepoint.length;

      if (group <= 0 || group > 4) {
        return;
      }

      if (emoji.emoji && (display === 'emoji' || display === 'both')) {
        codePointGroups[group].add(emoji.emoji);
      }

      if (emoji.text && (display === 'text' || display === 'both')) {
        codePointGroups[group].add(emoji.text);
      }
    });

    return codePointGroups;
  }).then(groups => {
    if (display === 'text') {
      return groups[1].toRegExp().source;
    }

    return [4, 3, 2, 1].map(group => `(?:${groups[group].toRegExp().source})`).join('|');
  }).then(regex => (0, _writeFile2.default)(_path2.default.join(__dirname, `../../regex/${fileName}.js`), regex, pattern => `module.exports = /${pattern}/;\n`, false));
}
/**
 * @copyright   2017, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 */


function generateExtra(rawData) {
  console.log('Generating shortnames regex pattern');

  return Promise.resolve(rawData).then(data => (0, _writeFile2.default)(_path2.default.join(__dirname, '../../regex/shortname.js'), ':[-+\\w]+:', pattern => `module.exports = /${pattern}/;\n`, false));
}

const data = (0, _packageData2.default)();

Promise.all([generateRegex(data, 'both'), generateRegex(data, 'emoji'), generateRegex(data, 'text'), generateExtra(data)]).then(() => {
  console.log(_chalk2.default.green('Regex generated successfully'));
}).catch(error => {
  console.log(_chalk2.default.red('Failed to generate regex pattern'));
  console.log(_chalk2.default.gray(error.message));
});