'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CACHE = exports.EMOJI_ONE = exports.EMOJI = undefined;
exports.default = packageData;

var _diacritics = require('diacritics');

var _unicodeEmojiData = require('unicode-emoji-data');

var _emoji = require('emojione/emoji.json');

var _emoji2 = _interopRequireDefault(_emoji);

var _createTags = require('./createTags');

var _createTags2 = _interopRequireDefault(_createTags);

var _createShortnames = require('./createShortnames');

var _createShortnames2 = _interopRequireDefault(_createShortnames);

var _extractGender = require('./extractGender');

var _extractGender2 = _interopRequireDefault(_extractGender);

var _extractSkinTone = require('./extractSkinTone');

var _extractSkinTone2 = _interopRequireDefault(_extractSkinTone);

var _fromHexToCodepoint = require('./fromHexToCodepoint');

var _fromHexToCodepoint2 = _interopRequireDefault(_fromHexToCodepoint);

var _constants = require('./constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const EMOJI = exports.EMOJI = (0, _unicodeEmojiData.expandEmojiData)(_unicodeEmojiData.emojiData); /**
                                                                                                    * @copyright   2017, Miles Johnson
                                                                                                    * @license     https://opensource.org/licenses/MIT
                                                                                                    * 
                                                                                                    */

const EMOJI_ONE = exports.EMOJI_ONE = {};

Object.keys(_emoji2.default).forEach(hexcode => {
  EMOJI_ONE[hexcode.toUpperCase()] = _emoji2.default[hexcode];
});

const CACHE = exports.CACHE = [];

function packageData() {
  if (CACHE.length > 0) {
    return CACHE;
  }

  EMOJI.forEach(emoji => {
    const { name, presentation, defaultPresentation } = emoji;
    const { variation = {} } = presentation;

    const emojiHexcode = variation.emoji || presentation.default;
    const textHexcode = variation.text || '';

    if (!emojiHexcode && !textHexcode) {
      return;
    }

    const emojiUnicode = emojiHexcode ? String.fromCodePoint(...(0, _fromHexToCodepoint2.default)(emojiHexcode.replace(_constants.WS_PATTERN, '-'))) : null;

    const textUnicode = textHexcode ? String.fromCodePoint(...(0, _fromHexToCodepoint2.default)(textHexcode.replace(_constants.WS_PATTERN, '-'))) : null;

    const hexcode = (emojiHexcode || textHexcode).replace(_constants.SEQUENCE_REMOVAL_PATTERN, '').trim().replace(_constants.WS_PATTERN, '-');

    const extraEmoji = {
      category: 'other',
      codepoint: (0, _fromHexToCodepoint2.default)(hexcode),
      display: defaultPresentation || 'emoji',
      emoji: emojiUnicode,
      gender: (0, _extractGender2.default)(name),
      hexcode,
      name,
      order: null,
      skin: (0, _extractSkinTone2.default)(name),
      shortnames: (0, _createShortnames2.default)(name),
      tags: (0, _createTags2.default)(name),
      text: textUnicode
    };

    if (EMOJI_ONE[hexcode]) {
      const emojiOne = EMOJI_ONE[hexcode];

      extraEmoji.category = emojiOne.category;
      extraEmoji.order = emojiOne.order;

      const tags = emojiOne.keywords.filter(kw => kw !== '').map(kw => (0, _diacritics.remove)(kw).replace(/ /g, '-').replace(/\.|“|”|’/g, ''));

      if (tags.length > 0) {
        extraEmoji.tags = tags;
      }

      extraEmoji.shortnames = [emojiOne.shortname].concat(emojiOne.shortname_alternates).map(sn => sn.replace(/:/g, ''));

      delete EMOJI_ONE[hexcode];
    }

    CACHE.push(extraEmoji);
  });

  CACHE.sort((a, b) => a.order - b.order);

  return CACHE;
}